@@ -15,4 +15,6 @@
 import semantyk
 
 def test_import():
-    print(semantyk)
\ No newline at end of file
+    print('Semantyk ' + semantyk.__version__)
+
+test_import()
\ No newline at end of file
